@@ -1,12 +1,11 @@
 """Main module."""
 import torch.nn as nn
-from transformers import BertModel
 import torch
 import numpy as np
 import pickle
 import os
 import clip
-from transformers import AutoTokenizer , AutoModel
+from transformers import AutoTokenizer, AutoModel
 from tqdm import tqdm
 
 os.environ['KMP_DUPLICATE_LIB_OK'] = 'True'
@@ -55,8 +54,8 @@ class Trclip:
                 return text_features if not return_numpy else text_features.detach().cpu().numpy()
 
     def get_results(self, images=None, texts=None, mode='per_image', text_features=None, image_features=None,
-                    use_original_text_encoder=False):
-        if mode not in ['per_image', 'per_text']:
+                    use_original_text_encoder=False, return_probs=False):
+        if mode not in ['per_image', 'per_text', 'text_retrieval', 'image_retrieval']:
             raise ValueError('Mode must be either per_image or per_text')
         with torch.no_grad():
             image_features = self.get_image_features(images) if image_features is None else image_features
@@ -64,11 +63,12 @@ class Trclip:
                                                    use_original_text_encoder=use_original_text_encoder) if text_features is None else text_features
             logit_scale = self.clip_model.logit_scale.exp().float().to(self.device)
             # cosine similarity as logits
-            if mode == 'per_image':
+            if mode == 'per_image' or mode == 'text_retrieval':
                 per_mode_probs = logit_scale * image_features @ text_features.t()
-            elif mode == 'per_text':
+            elif mode == 'per_text' or mode == 'image_retrieval':
                 per_mode_probs = logit_scale * text_features @ image_features.t()
-
+            if return_probs:
+                return per_mode_probs
             per_mode_probs = per_mode_probs.softmax(dim=-1).cpu().detach().numpy()
         # per_mode_probs = np.around(per_mode_probs, decimals=2)
         per_mode_indices = [np.argsort(prob)[::-1] for prob in per_mode_probs]
